@@ -1,6 +1,6 @@
 #############################################################################
 #
-# Copyright (c) 2006 Zope Corporation and Contributors.
+# Copyright (c) 2006 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -86,10 +86,10 @@ def source_release(args=None):
     try:
 
         if url.startswith('file://'):
-            shutil.copytree(urlparse.urlparse(url)[2], co1)
+            shutil.copytree(urlparse.urlparse(url)[2], co1, symlinks=True)
         else:
             _system('svn', 'export', url, co1)
-        shutil.copytree(co1, co2)
+        shutil.copytree(co1, co2, symlinks=True)
         cache = os.path.join(co2, 'release-distributions')
         os.mkdir(cache)
         buildout = zc.buildout.buildout.Buildout(
@@ -115,16 +115,21 @@ def source_release(args=None):
         os.chdir(here)
 
         env = pkg_resources.Environment([eggs_directory])
+        projects = ['zc.buildout']
+        if env['setuptools']:
+            projects.append('setuptools')
+        else:
+            projects.append('distribute')
         dists = [env[project][0].location
-                 for project in ('zc.buildout', 'setuptools')]
+                 for project in projects]
 
         eggs = os.path.join(co2, reggs)
         os.mkdir(eggs)
         for dist in dists:
             if os.path.isdir(dist):
                 shutil.copytree(dist,
-                                os.path.join(eggs, os.path.basename(dist))
-                                )
+                                os.path.join(eggs, os.path.basename(dist)),
+                                symlinks=True)
             else:
                 shutil.copy(dist, eggs)
 
